[java-opensaml COMMIT] in /trunk/opensaml-saml-api/src/main/java/org/opensaml/saml: common/messaging/context/SamlArti...

noreply at shibboleth.net noreply at shibboleth.net
Tue Dec 17 12:51:25 EST 2013


Author: scantor
Date: Tue Dec 17 12:51:25 2013
New Revision: 3518

URL: http://svn.shibboleth.net/view/java-opensaml?rev=3518&view=rev
Log:
Fix some mistakenly named methods.

Modified:
    trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/common/messaging/context/SamlArtifactContext.java
    trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml1/binding/artifact/SAML1ArtifactType0002Builder.java
    trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml2/binding/artifact/SAML2ArtifactType0004Builder.java

Modified: trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/common/messaging/context/SamlArtifactContext.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/common/messaging/context/SamlArtifactContext.java?rev=3518&r1=3517&r2=3518&view=diff
==============================================================================
--- trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml1/binding/artifact/SAML1ArtifactType0002Builder.java (original)
+++ trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml1/binding/artifact/SAML1ArtifactType0002Builder.java Tue Dec 17 12:51:25 2013
@@ -78,12 +78,12 @@
     protected String getArsEndpointUrl(MessageContext<SAMLObject> requestContext) {
         SamlArtifactContext artifactContext = getArtifactContext(requestContext);
 
-        if (artifactContext == null || artifactContext.getSourceAttributeResolutionServiceEndpointUrl() == null) {
+        if (artifactContext == null || artifactContext.getSourceArtifactResolutionServiceEndpointURL() == null) {
             log.error("No artifact resolution service endpoint URL is available");
             return null;
         }
 

[... 27 lines stripped ...]


More information about the commits mailing list
--- trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/common/messaging/context/SamlArtifactContext.java (original)
+++ trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/common/messaging/context/SamlArtifactContext.java Tue Dec 17 12:51:25 2013
@@ -32,11 +32,11 @@
     /** The artifact source entityID. */
     private String sourceEntityId;
     
-    /** The artifact source attribute resolutions server endpoint URL. */
-    private String sourceAttributeResolutionServiceEndpointUrl;
+    /** The artifact resolution endpoint URL. */
+    private String sourceArtifactResolutionServiceEndpointUrl;
     
-    /** The artifact source attribute resolutions server endpoint index. */
-    private Integer sourceAttributeResolutionServiceEndpointIndex;
+    /** The artifact resolution endpoint index. */
+    private Integer sourceArtifactResolutionServiceEndpointIndex;
 
     /**
      * Gets the artifact type.
@@ -75,39 +75,39 @@
     }
 
     /**
      * Get the source attribute resolution service endpoint URL.
      * 
      * @return the URL
      */
-    @Nullable public String getSourceAttributeResolutionServiceEndpointUrl() {
-        return sourceAttributeResolutionServiceEndpointUrl;
+    @Nullable public String getSourceArtifactResolutionServiceEndpointURL() {
+        return sourceArtifactResolutionServiceEndpointUrl;
     }
 
     /**
      * Set the source attribute resolution service endpoint URL.
      * 
      * @param url the new URL
      */
-    public void setSourceAttributeResolutionServiceEndpointUrl(@Nullable final String url) {
-        sourceAttributeResolutionServiceEndpointUrl = url;
+    public void setSourceArtifactResolutionServiceEndpointURL(@Nullable final String url) {
+        sourceArtifactResolutionServiceEndpointUrl = url;
     }
 
     /**
      * Get the source attribute resolution service endpoint index.
      * 
      * @return the index
      */
-    @Nullable public Integer getSourceAttributeResolutionServiceEndpointIndex() {
-        return sourceAttributeResolutionServiceEndpointIndex;
+    @Nullable public Integer getSourceArtifactResolutionServiceEndpointIndex() {
+        return sourceArtifactResolutionServiceEndpointIndex;
     }
 
     /**
      * Set the source attribute resolution service endpoint index.
      * 
      * @param index the new index
      */
-    public void setSourceAttributeResolutionServiceEndpointIndex(@Nullable final Integer index) {
-        sourceAttributeResolutionServiceEndpointIndex = index;
+    public void setSourceArtifactResolutionServiceEndpointIndex(@Nullable final Integer index) {
+        sourceArtifactResolutionServiceEndpointIndex = index;
     }
 
 }
@@ -75,39 +75,39 @@
 
     /**
-     * Get the source attribute resolution service endpoint URL.
+     * Get the artifact resolution service endpoint URL.
      * 
      * @return the URL
@@ -75,39 +75,39 @@
 
     /**
-     * Set the source attribute resolution service endpoint URL.
+     * Set the artifact resolution service endpoint URL.
      * 
      * @param url the new URL
@@ -75,39 +75,39 @@
 
     /**
-     * Get the source attribute resolution service endpoint index.
+     * Get the artifact resolution service endpoint index.
      * 
      * @return the index
@@ -75,39 +75,39 @@
 
     /**
-     * Set the source attribute resolution service endpoint index.
+     * Set the source artifact resolution service endpoint index.
      * 
      * @param index the new index

Modified: trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml1/binding/artifact/SAML1ArtifactType0002Builder.java
URL: http://svn.shibboleth.net/view/java-opensaml/trunk/opensaml-saml-api/src/main/java/org/opensaml/saml/saml1/binding/artifact/SAML1ArtifactType0002Builder.java?rev=3518&r1=3517&r2=3518&view=diff
==============================================================================